'use strict';

var _ava = require('ava');

var _ava2 = _interopRequireDefault(_ava);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _lodash = require('lodash');

var _ = require('.');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const ok = _chalk2.default.bold(`${_chalk2.default.green('✔')}   found 0 problems, 0 warnings \n    (Need help? -> https://github.com/conventional-changelog/commitlint#what-is-commitlint )\n\n`);

(0, _ava2.default)('does nothing without arguments', t => {
	const actual = (0, _2.default)();
	t.deepEqual(actual, ok);
});

(0, _ava2.default)('does nothing without report results', t => {
	const actual = (0, _2.default)({ results: [] });
	t.deepEqual(actual, ok);
});

(0, _ava2.default)('does nothing without .errors and .warnings', t => {
	const actual = (0, _2.default)({ results: [{}] });
	t.deepEqual(actual, ok);
});

(0, _ava2.default)('returns empty summary of problems for empty .errors and .warnings', t => {
	const actual = (0, _2.default)({
		results: [{
			errors: [],
			warnings: []
		}]
	});

	t.true(actual.includes('0 problems, 0 warnings'));
});

(0, _ava2.default)('returns a correct of empty .errors and .warnings', t => {
	const actualError = (0, _2.default)({
		results: [{
			errors: [{
				level: 2,
				name: 'error-name',
				message: 'There was an error'
			}]
		}]
	});

	const actualWarning = (0, _2.default)({
		results: [{
			warnings: [{
				level: 1,
				name: 'warning-name',
				message: 'There was a problem'
			}]
		}]
	});

	t.true((0, _lodash.includes)(actualError, 'There was an error'));
	t.true((0, _lodash.includes)(actualError, '1 problems, 0 warnings'));
	t.true((0, _lodash.includes)(actualWarning, 'There was a problem'));
	t.true((0, _lodash.includes)(actualWarning, '0 problems, 1 warnings'));
});

(0, _ava2.default)('uses appropriate signs by default', t => {
	const actualError = (0, _2.default)({
		results: [{
			errors: [{
				level: 2,
				name: 'error-name',
				message: 'There was an error'
			}]
		}]
	});

	const actualWarning = (0, _2.default)({
		results: [{
			warnings: [{
				level: 1,
				name: 'warning-name',
				message: 'There was a problem'
			}]
		}]
	});

	t.true((0, _lodash.includes)(actualError, '✖'));
	t.true((0, _lodash.includes)(actualWarning, '⚠'));
});

(0, _ava2.default)('uses signs as configured', t => {
	const options = { signs: ['HNT', 'WRN', 'ERR'] };
	const actualError = (0, _2.default)({
		results: [{
			errors: [{
				level: 2,
				name: 'error-name',
				message: 'There was an error'
			}]
		}]
	}, options);

	const actualWarning = (0, _2.default)({
		results: [{
			warnings: [{
				level: 1,
				name: 'warning-name',
				message: 'There was a problem'
			}]
		}]
	}, options);

	t.true((0, _lodash.includes)(actualError, 'ERR'));
	t.true((0, _lodash.includes)(actualWarning, 'WRN'));
});

(0, _ava2.default)('format result provides summary without arguments', t => {
	const actual = (0, _.formatResult)();
	const actualText = actual.join('\n');

	t.true((0, _lodash.includes)(actualText, '0 problems, 0 warnings'));
});

(0, _ava2.default)('format result transforms error to text', t => {
	const actual = (0, _.formatResult)({
		errors: [{
			level: 2,
			name: 'error-name',
			message: 'There was an error'
		}]
	});

	const actualText = actual.join('\n');

	t.true((0, _lodash.includes)(actualText, 'error-name'));
	t.true((0, _lodash.includes)(actualText, 'There was an error'));
	t.true((0, _lodash.includes)(actualText, '1 problems, 0 warnings'));
});

(0, _ava2.default)('format result transforms warning to text', t => {
	const actual = (0, _.formatResult)({
		warnings: [{
			level: 1,
			name: 'warning-name',
			message: 'There was a warning'
		}]
	});

	const actualText = actual.join('\n');

	t.true((0, _lodash.includes)(actualText, 'warning-name'));
	t.true((0, _lodash.includes)(actualText, 'There was a warning'));
	t.true((0, _lodash.includes)(actualText, '0 problems, 1 warnings'));
});
//# sourceMappingURL=index.test.js.map